@@ -13,7 +13,7 @@ int setup_listening_socket(int port, int ipv6);
  * To avoid making large changes in tests, define a helper
  * function that wraps posix_memalign as our own aligned_alloc.
  */
-void *aligned_alloc(size_t alignment, size_t size);
+void *t_aligned_alloc(size_t alignment, size_t size);
 
 void t_error(int status, int errnum, const char *format, ...);
 
